@@ -10,35 +10,28 @@ import org.flexdock.docking.defaults.DefaultDockingStrategy;
 import org.flexdock.docking.defaults.StandardBorderManager;
 import org.flexdock.plaf.common.border.ShadowBorder;
 
-public class MyDockingPort extends DefaultDockingPort
-{
+public class MyDockingPort extends DefaultDockingPort {
 
-    static
-    {
+    static {
         initStatic();
     }
 
-    private static void initStatic()
-    {
+    private static void initStatic() {
         DockingManager.setDockingStrategy(MyDockingPort.class, new MyDockingStrategy());
     }
 
-    public MyDockingPort()
-    {
+    public MyDockingPort() {
         this(new ShadowBorder());
     }
 
-    public MyDockingPort(Border portletBorder)
-    {
+    public MyDockingPort(Border portletBorder) {
         super();
-        if (portletBorder != null)
-        {
+        if (portletBorder != null) {
             setBorderManager(new StandardBorderManager(portletBorder));
         }
     }
 
-    protected JTabbedPane createTabbedPane()
-    {
+    protected JTabbedPane createTabbedPane() {
         JTabbedPane tabbed = super.createTabbedPane();
         tabbed.putClientProperty("jgoodies.embeddedTabs", Boolean.TRUE);
         return tabbed;
@@ -46,14 +39,12 @@ public class MyDockingPort extends DefaultDockingPort
 
     // ***************
 
-    private static class MyDockingStrategy extends DefaultDockingStrategy
-    {
-        protected DockingPort createDockingPortImpl(DockingPort base)
-        {
+    private static class MyDockingStrategy extends DefaultDockingStrategy {
+        protected DockingPort createDockingPortImpl(DockingPort base) {
             return new MyDockingPort();
         }
-        
-        
+
+
     }
 
 }
\ No newline at end of file
