@@ -8,8 +8,8 @@ import java.awt.event.ActionListener;
 
 import javax.swing.Timer;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+
+
 import org.flexdock.dockbar.DockbarManager;
 import org.flexdock.dockbar.ViewPane;
 
@@ -19,7 +19,6 @@ import org.flexdock.dockbar.ViewPane;
  * @author Christopher Butler
  */
 public class Animation implements Runnable, ActionListener {
-    private static Log log = LogFactory.getLog(Animation.class);
 
     private static int ANIMATION_INTERVAL = 20;
     private static int TOTAL_FRAME_COUNT = 5;
@@ -99,7 +98,8 @@ public class Animation implements Runnable, ActionListener {
             try {
                 lock.wait();
             } catch(InterruptedException e) {
-                log.debug(e.getMessage(), e);
+                System.err.println("Exception: " +e.getMessage());
+                e.printStackTrace();
             }
         }
     }
