@@ -5,8 +5,8 @@ package org.flexdock.perspective.event;
 
 import java.util.EventListener;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+
+
 import org.flexdock.event.Event;
 import org.flexdock.event.EventHandler;
 
@@ -14,7 +14,6 @@ import org.flexdock.event.EventHandler;
  * @author Christopher Butler
  */
 public class PerspectiveEventHandler extends EventHandler {
-    private static Log log = LogFactory.getLog(PerspectiveEventHandler.class);
 
     private static final PerspectiveEventHandler SINGLETON = new PerspectiveEventHandler();
 
@@ -45,7 +44,6 @@ public class PerspectiveEventHandler extends EventHandler {
             consumer.perspectiveReset(event);
             break;
         default:
-            log.warn("Event not handled: unknown type " + eventType);
             break;
         }
     }
