@@ -17,14 +17,13 @@ import javax.swing.Action;
 import javax.swing.Icon;
 import javax.swing.border.Border;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+
+
 
 /**
  * @author Christopher Butler
  */
 public class PropertySet {
-    private static Log log = LogFactory.getLog(PropertySet.class);
 
     private HashMap properties;
     private String name;
@@ -103,7 +102,8 @@ public class PropertySet {
         try {
             return Integer.parseInt(string);
         } catch(NumberFormatException e) {
-            log.debug(e.getMessage(), e);
+            System.err.println("Exception: " +e.getMessage());
+            e.printStackTrace();
             return 0;
         }
     }
@@ -128,7 +128,8 @@ public class PropertySet {
         try {
             return Boolean.valueOf( string).booleanValue();
         } catch(NumberFormatException e) {
-            log.debug(e.getMessage(), e);
+            System.err.println("Exception: " +e.getMessage());
+            e.printStackTrace();
             return false;
         }
     }
