@@ -11,8 +11,8 @@ import java.awt.Insets;
 import javax.swing.border.Border;
 import javax.swing.plaf.ColorUIResource;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+
+
 import org.flexdock.plaf.resources.ColorResourceHandler;
 import org.flexdock.plaf.resources.ResourceHandler;
 
@@ -20,7 +20,6 @@ import org.flexdock.plaf.resources.ResourceHandler;
  * @author Christopher Butler
  */
 public class SquareBevelBorderResource extends ResourceHandler {
-    private static Log log = LogFactory.getLog(SquareBevelBorderResource.class);
 
     private static final ColorUIResource DEFAULT_COLOR = new ColorUIResource(Color.WHITE);
 
@@ -38,7 +37,8 @@ public class SquareBevelBorderResource extends ResourceHandler {
         try {
             return Integer.parseInt(data);
         } catch(Exception e) {
-            log.debug(e.getMessage(), e);
+            System.err.println("Exception: " +e.getMessage());
+            e.printStackTrace();
             return 1;
         }
     }
